#include <unordered_set>/*{{{*/
#include <algorithm>
#include <iostream>
#include <fstream>
#include <numeric>
#include <sstream>
#include <cassert>
#include <string>
#include <vector>
#include <stack>
#include <map>
#include <set>
using namespace std;/*}}}*/

using namespace std;
typedef long long ll;

enum JudgeCode:int{
  judge_error=1,
  correct=42,
  wrong_answer=43,
};

bool is_integer(string const &s){
  return all_of(s.begin(), s.end(), ::isdigit);
}

int64_t read_answer(
    istream &in,
    vector<int64_t> const &costs,
    vector<unordered_set<size_t>> const &deps,
    string const party,
    JudgeCode const failure_code){

  // Get the output tokens.
  vector<string> buffer;
  for (string s; in>>s;){
    transform(s.begin(), s.end(), s.begin(), ::tolower);
    buffer.emplace_back(s);
  }
  if (buffer.empty()){
    cout<<party<<" output nothing"<<endl;
    exit(failure_code);
  }

  // Get party's claimed answer.
  int64_t answer;
  {
    stringstream sst(buffer[0]);
    if (not (is_integer(buffer[0]) and (sst>>answer))) {
      cout<<party<<" did not output an int64_t"<<endl;
      exit(failure_code);
    }
  }

  // Read the party's answer certificate.
  unordered_set<size_t> res;
  for (int i=1; i<buffer.size(); i++){
    stringstream sst(buffer[i]);
    size_t x;
    if (not (is_integer(buffer[i]) and (sst>>x))){
      cout<<"Token "<<i+1<<" in "<<party<<" output ("<<buffer[i]<<") is not an integer"<<endl;
      exit(failure_code);
    }
    if (not (1 <= x and x <= costs.size())){
      cout<<"Output node "<<x<<" is out of bounds [1,"<<costs.size()<<"]"<<endl;
      exit(failure_code);
    }
    if (not res.insert(x-1).second){
      cout<<"Output node "<<x<<" used more than once"<<endl;
      exit(failure_code);
    }
  }

  // Turn the certificate into a score.
  int64_t score=0;
  bool valid=true;
  for (int i=0; i<costs.size(); i++){
    if (res.count(i)){
      for (auto j: deps[i]){
        if (not res.count(j)){
          cout<<party<<" used node "<<i+1<<" but not dependency node "<<j+1<<endl;
          exit(failure_code);
        }
      }
      score+=costs[i];
    }
  }

  // Validate the certificate and the answer are the same.
  if (score!=answer){
    cout<<party<<" got score "<<score<<" but output answer "<<answer<<endl;
    exit(failure_code);
  }

  return score;
}

int main(int argc,char **argv){
  if (argc<3){
    cerr<<"usage: "<<argv[0]<<" testcase.in testcase.ans [feedback]< team.out"<<endl;
    return judge_error;
  }
  else if (argc>3){
    assert(freopen((string(argv[3])+"/feedback.txt").c_str(),"w",stdout));
  }
  else if (argc>4){
    cerr<<"warning: ignoring "<<argc-4<<" extra arguments"<<endl;
  }
  ifstream canonical_input(argv[1]);
  ifstream canonical_output(argv[2]);
  auto &team_output = cin;

  // Read input.
  size_t n; assert(canonical_input>>n);
  vector<int64_t> costs(n);
  vector<unordered_set<size_t>> deps(n);
  for (size_t i=0; i<n; i++){
    assert(canonical_input>>costs[i]);
    size_t m;
    assert(canonical_input>>m);
    for (size_t j=0; j<m; j++){
      size_t dep; assert(canonical_input>>dep);
      assert(deps[i].insert(dep-1).second);
    }
  }

  // Read expected and team answers.
  int64_t const expect = read_answer(canonical_output, costs, deps, "Jury", judge_error);
  int64_t const team = read_answer(team_output, costs, deps, "Team", wrong_answer);

  if (expect==team){
    cout<<"Correct. Good job!"<<endl;
    return correct;
  }
  if (team<expect){
    cout<<"Team found an answer of "<<team<<". This is worse than jury answer of "<<expect<<endl;
    return wrong_answer;
  }
  if (expect<team){
    cout<<"Team found an answer of "<<team<<". This is better than jury answer of "<<expect<<endl;
    return judge_error;
  }
  assert(false);
  return -1;
}
