#include <bits/stdc++.h>
using namespace std;

const long INF = LONG_MAX/2;

struct flow_network {
	struct edge { long to, cap; };
	
	long n, s, t;
	vector<long> ptr, dist;
	vector<vector<long>> adj;
	vector<edge> e;

	flow_network(long n, long s, long t): n(n), s(s), t(t), adj(n) { }

	void add_edge(long a, long b, long c) {
		adj[a].push_back(e.size());
		e.push_back({b,c});
		adj[b].push_back(e.size());
		e.push_back({a,0});
	}
	
	bool bfs() {
		dist.assign(n,INF);
		queue<long> q;
		dist[s] = 0, q.push(s);
		while (!q.empty()) {
			long i = q.front(); q.pop();
			for (long j: adj[i]) if (e[j].cap) {
				if (dist[e[j].to] < INF) continue;
				dist[e[j].to] = dist[i]+1, q.push(e[j].to);
			}
		}
		return dist[t] < INF;
	}

	long dfs(long i, long cap) {
		if (!cap || i == t) return cap;
		for (; ptr[i] < long(adj[i].size()); ptr[i]++) {
			long j = adj[i][ptr[i]];
			if (dist[e[j].to] != dist[i]+1) continue;
			if (long c = dfs(e[j].to, min(cap,e[j].cap))) {
				e[j].cap -= c, e[j^1].cap += c;
				return c;
			}
		}
		return 0;
	}

	pair<long, vector<long>> max_flow() {
		long flow = 0;
		while (bfs()) {
			ptr.assign(n,0);
			while (long c = dfs(s,INF)) flow += c;
		}
		return {flow, dist};
	}
};

int main() {
	long n; cin >> n;
	flow_network F(n+2,n,n+1);

	long res = 0;
	for (long i = 0; i < n; i++) {
		long w, m;
		cin >> w >> m;
		res += max(w,0l);
		if (w > 0) F.add_edge(n,i,w);
		else F.add_edge(i,n+1,-w);
		
		while (m--) {
			long j; cin >> j;
			F.add_edge(i,j-1,INF);
		}
	}
  auto [flow, dist] = F.max_flow();
	res -= flow;
	cout << res << endl;
  for (int i = 0 ; i < n; i++) {
    if (dist[i] != INF) {
      cout << i+1 << " ";
    }
  }
  cout << endl;
}
