#include <bits/stdc++.h>
using namespace std;

const long INF = LONG_MAX/2;

struct flow_network {
	struct edge { long to, cap; };
	
	long n, s, t, k = 0;
	vector<long> ex, h;
	vector<vector<long>> adj;
	vector<edge> e;
	queue<long> q;

	flow_network(long n, long s, long t): n(n), s(s), t(t), ex(n), h(n), adj(n) { }

	void add_edge(long a, long b, long c) {
		adj[a].push_back(e.size());
		e.push_back({b,c});
		adj[b].push_back(e.size());
		e.push_back({a,0});
	}
	
	void push(long j, long c) {
		long a = e[j^1].to, b = e[j].to;
		if (ex[b] == 0 && b != s && b != t) q.push(b);
		ex[a] -= c, ex[b] += c;
		e[j].cap -= c, e[j^1].cap += c;
	}
	
	void discharge(long i) {
		long hmin = INF;
		for (long j: adj[i]) if (e[j].cap) {
			if (h[i] > h[e[j].to]) {
				push(j,min(ex[i],e[j].cap));
				if (ex[i] == 0) return;
			} else {
				hmin = min(hmin, h[e[j].to]+1);
			}
		}
		h[i] = hmin;
		discharge(i);
	}

	long max_flow() {
		h[s] = n;
		for (long j: adj[s]) if (e[j].cap) push(j,e[j].cap);
		while (!q.empty()) {
			long i = q.front(); q.pop();
			if (ex[i]) discharge(i);
		}
		return ex[t];
	}

  vector<bool> find_cut() {
    vector<bool> mark(n); mark[s] = 1;
    q.push(s);
    while (!q.empty()) {
      for (long j: adj[q.front()]) {
        if (e[j].cap != 0 && !mark[e[j].to]) {
          mark[e[j].to] = 1;
          q.push(e[j].to);
        }
      }
      q.pop();
    }
    return mark;
  }
};

int main() {
	long n; cin >> n;
	flow_network F(n+2,n,n+1);

	long res = 0;
	for (long i = 0; i < n; i++) {
		long w, m;
		cin >> w >> m;
		res += max(w,0l);
		if (w > 0) F.add_edge(n,i,w);
		else F.add_edge(i,n+1,-w);
		
		while (m--) {
			long j; cin >> j;
			F.add_edge(i,j-1,INF);
		}
	}
	res -= F.max_flow();
	cout << res << endl;
  vector<bool> mark = F.find_cut();
  for (int i = 0 ; i < n; i++) {
    if (mark[i]) {
      cout << i+1 << " ";
    }
  }
  cout << endl;
}
