import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.*;

public class jeroen {
	static BufferedReader in = new BufferedReader(new InputStreamReader(System.in));

	public static void main(String[] args) throws Exception {
		// Read input
		int n = Integer.valueOf(in.readLine());
		int[] x = new int[n];
		int[] d = new int[n];
		int[][] b = new int[n][];
		for(int i = 0; i < n; i++) {
			String[] ps = in.readLine().split(" ");
			x[i] = Integer.valueOf(ps[0]);
			d[i] = Integer.valueOf(ps[1]);
			b[i] = new int[d[i]];
			for(int j = 0; j < d[i]; j++)
				b[i][j] = Integer.valueOf(ps[2+j]) - 1;
		}

		// Construct flow graph
		MaxFlow mf = new MaxFlow(n);
		int ans = 0;
		for(int i = 0; i < n; i++) {
			if(x[i] < 0)
				mf.Add(i, mf.Sink, -x[i]);
			else {
				mf.Add(mf.Source, i, x[i]);
				ans += x[i];
			}
			for(int j = 0; j < d[i]; j++)
				mf.Add(i, b[i][j], Integer.MAX_VALUE / 3);
		}

		// The answer is the sum of positive topics minus the min-cut
		ans -= mf.NetworkFlow();
		System.out.println(ans);
		for(int i = 0; i < n; i++)
			if(mf.parent[i] != -1)
				System.out.print((i+1) + " ");
		System.out.println();
	}
}

class MaxFlow
{
	public int Nodes;
	public int Source;
	public int Sink;
	TreeSet<Integer>[] Neighbours;
	HashMap<Integer,Integer>[] Capacity;
	HashMap<Integer,Integer>[] Flow;

	public MaxFlow(int Nodes)
	{
		this.Nodes = Nodes + 2;
		this.Source = Nodes;
		this.Sink = Nodes + 1;
		Neighbours = new TreeSet[this.Nodes];
		Capacity = new HashMap[this.Nodes];
		Flow = new HashMap[this.Nodes];
		for (int i = 0; i < this.Nodes; i++) {
			Neighbours[i] = new TreeSet<>();
			Flow[i] = new HashMap<>();
			Capacity[i] = new HashMap<>();
		}
	}

	public void Add(int From, int To, int Cap)
	{
		Neighbours[From].add(To);
		Neighbours[To].add(From);
		if (Capacity[From].get(To) == null) {
			Capacity[From].put(To, 0);
		}
		if (Capacity[To].get(From) == null) {
			Capacity[To].put(From, 0);
		}
		Capacity[From].put(To, Capacity[From].get(To) + Cap);
		if (Flow[From].get(To) == null) {
			Flow[From].put(To, 0);
		}
		if (Flow[To].get(From) == null) {
			Flow[To].put(From, 0);
		}
	}

	public int[] cap, parent;
	public int NetworkFlow()
	{
		parent = new int[Nodes];
		cap = new int[Nodes];

		int total = 0;
		while (true)
		{
			for (int i = 0; i < Nodes; i++)
				parent[i] = -1;
			parent[this.Source] = -2;
			cap[this.Source] = Integer.MAX_VALUE;
			Queue<Integer> Q = new LinkedList<Integer>();
			Q.offer(this.Source);
			while (!Q.isEmpty() && parent[this.Sink] == -1)
			{
				int act = Q.poll();
				for(int next : Neighbours[act])
				{
					if (parent[next] == -1 && Capacity[act].get(next) > Flow[act].get(next))
					{
						parent[next] = act;
						cap[next] = Math.min(cap[act], Capacity[act].get(next) - Flow[act].get(next));
						Q.offer(next);
					}
				}
			}

			if (parent[this.Sink] == -1)
				return total;

			total += cap[this.Sink];
			int j = this.Sink;
			while (j != this.Source)
			{
				Flow[parent[j]].put(j, Flow[parent[j]].get(j) + cap[this.Sink]);
				Flow[j].put(parent[j], Flow[j].get(parent[j]) - cap[this.Sink]);
				j = parent[j];
			}
		}
	}
}
